@@ -264,9 +264,6 @@ lbav_entry_setup_matches(LibBalsaAddressView * address_view,
 
 /*
  *     Idle callback to set the GtkTreeView's cursor.
- *
- *     Scheduled with gdk_threads_add_idle, so it already holds the GDK
- *     lock, and its GSource has not been removed.
  */
 static gboolean
 lbav_ensure_blank_line_idle_cb(LibBalsaAddressView * address_view)
@@ -349,9 +346,7 @@ lbav_ensure_blank_line(LibBalsaAddressView * address_view,
 
     if (!address_view->focus_idle_id)
         address_view->focus_idle_id =
-            gdk_threads_add_idle((GSourceFunc)
-                                 lbav_ensure_blank_line_idle_cb,
-                                 address_view);
+        	g_idle_add((GSourceFunc) lbav_ensure_blank_line_idle_cb, address_view);
 }
 
 /*
@@ -520,11 +515,11 @@ lbav_set_text(LibBalsaAddressView * address_view, const gchar * text)
         else {
             /* No valid addresses found; just set the new text and keep
              * the focus in this line. */
-            gchar *name = g_strdup(text);
-            lbav_clean_text(name);
+            gchar *text_dup = g_strdup(text);
+            lbav_clean_text(text_dup);
             gtk_list_store_set(address_store, &iter,
-                               ADDRESS_NAME_COL, name, -1);
-            g_free(name);
+                               ADDRESS_NAME_COL, text_dup, -1);
+            g_free(text_dup);
         }
         return;
     }
