@@ -33,39 +33,29 @@
 #include <glib/gi18n.h>
 
 static const gchar *permanent_prefixes[] = {
-/*	BALSA_DATA_PREFIX,
-	BALSA_STD_PREFIX,
-	GNOME_DATA_PREFIX
-	GNOME_STD_PREFIX,
-	GNOME_LIB_PREFIX,*/
-    BALSA_COMMON_PREFIXES,
+    BALSA_DATA_PREFIX,
     "src",
-    ".",
-    NULL
+    "."
 };
 
 /* filename is the filename (naw!)
  * splice is what to put in between the prefix and the filename, if desired
- * prefixes is a null-termed array of strings of prefixes to try. There are defaults that are always
- *   tried.
  * We ignore proper slashing of names. Ie, /prefix//splice//file won't be caught.
  */
 gchar *
-balsa_file_finder(const gchar * filename, const gchar * splice,
-		  const gchar ** prefixes, gboolean warn)
+balsa_file_finder(const gchar  * filename,
+                  const gchar  * splice)
 {
     gchar *cat;
-    int i;
+    guint i;
 
     g_return_val_if_fail(filename, NULL);
 
     if (splice == NULL)
 	splice = "";
 
-    for (i = 0; permanent_prefixes[i]; i++) {
-	cat =
-	    g_strconcat(permanent_prefixes[i], G_DIR_SEPARATOR_S, splice,
-			G_DIR_SEPARATOR_S, filename, NULL);
+    for (i = 0; i < G_N_ELEMENTS(permanent_prefixes); i++) {
+	cat = g_build_filename(permanent_prefixes[i], splice, filename, NULL);
 
 	if (g_file_test(cat, G_FILE_TEST_IS_REGULAR))
 	    return cat;
@@ -73,28 +63,13 @@ balsa_file_finder(const gchar * filename, const gchar * splice,
 	g_free(cat);
     }
 
-    if(prefixes) {
-        for (i = 0; prefixes[i]; i++) {
-            cat =
-                g_strconcat(prefixes[i], G_DIR_SEPARATOR_S, splice,
-			    G_DIR_SEPARATOR_S, filename, NULL);
-            
-            if (g_file_test(cat, G_FILE_TEST_IS_REGULAR))
-                return cat;
-            
-            g_free(cat);
-        }
-    }
-    cat =  g_strconcat("images", G_DIR_SEPARATOR_S, filename, NULL);
+    cat = g_build_filename("images", filename, NULL);
     if (g_file_test(cat, G_FILE_TEST_IS_REGULAR))
         return cat;
     g_free(cat);
 
-    if (warn)
-        g_warning("Cannot find expected file “%s” "
-                  "(spliced with “%s”) %s extra prefixes",
-	          filename, splice,
-                  prefixes ? "even with" : "with no");
+    g_warning("Cannot find expected file “%s” (spliced with “%s”)", filename, splice);
+
     return NULL;
 }
 
@@ -133,10 +108,10 @@ libbalsa_icon_finder(GtkWidget         * widget,
                      GtkIconSize         size)
 {
     const gchar *content_type;
-    gchar *icon = NULL;
     GdkPixbuf *pixbuf = NULL;
     gint width, height;
     GtkIconTheme *icon_theme;
+    GIcon *icon;
 
     if (!gtk_icon_size_lookup(size, &width, &height))
         width = 16;
@@ -146,63 +121,40 @@ libbalsa_icon_finder(GtkWidget         * widget,
     else if (for_file) {
         content_type = libbalsa_vfs_get_mime_type(for_file);
     } else
-	content_type = "application/octet-stream";
+        content_type = "application/octet-stream";
 
     /* ask GIO for the icon */
-    if ((icon_theme = gtk_icon_theme_get_default())) {
-        GIcon * icon = g_content_type_get_icon(content_type);
+    if ((icon_theme = gtk_icon_theme_get_default()) == NULL)
+        return NULL;
 
-        if (icon && G_IS_THEMED_ICON(icon)) {
-            int i = 0;
+    icon = g_content_type_get_icon(content_type);
+
+    if (icon != NULL) {
+        if (G_IS_THEMED_ICON(icon)) {
+            gint i;
             GStrv icon_names;
 
             g_object_get(G_OBJECT(icon), "names", &icon_names, NULL);
-            while (!pixbuf && icon_names && icon_names[i]) {
-                pixbuf = gtk_icon_theme_load_icon(icon_theme, icon_names[i],
-                                                  width, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
-                i++;
+
+            if (icon_names != NULL) {
+                for (i = 0; pixbuf == NULL && icon_names[i] != NULL; i++) {
+                    pixbuf =
+                        gtk_icon_theme_load_icon(icon_theme, icon_names[i], width,
+                                                 GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
+                }
+                g_strfreev(icon_names);
             }
-            g_strfreev(icon_names);
-            g_object_unref(icon);
-
-            /* last resort: try gnome-mime-<base mime type> */
-            if (!pixbuf) {
-                gchar * base_type_icon = g_strdup_printf("gnome-mime-%s", content_type);
-                gchar * slash = strchr(base_type_icon, '/');
-
-                if (slash)
-                    *slash = '\0';
-                pixbuf = gtk_icon_theme_load_icon(icon_theme, base_type_icon,
-                                                   width, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
-                g_free(base_type_icon);
-            }
-
-            /* return if we found a proper pixbuf */
-	    if (pixbuf) {
-		if (used_type)
-		    *used_type = g_strdup(content_type);
-		return pixbuf;
-	    }
         }
+        g_object_unref(icon);
     }
 
-    /* load the pixbuf */
-    if (icon == NULL)
-	pixbuf = libbalsa_default_attachment_pixbuf(width);
-    else {
-	GdkPixbuf *tmp_pb;
-	
-	if ((tmp_pb = gdk_pixbuf_new_from_file(icon, NULL))) {
-	    pixbuf = gdk_pixbuf_scale_simple(tmp_pb, width, width,
-					     GDK_INTERP_BILINEAR);
-	    g_object_unref(tmp_pb);
-	} else
-	    pixbuf = libbalsa_default_attachment_pixbuf(width);
-	g_free(icon);
+    if (pixbuf == NULL) {
+        /* load the default pixbuf */
+        pixbuf = libbalsa_default_attachment_pixbuf(width);
     }
-    
+
     if (used_type)
         *used_type = g_strdup(content_type);
-    
+
     return pixbuf;
 }
