@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -383,7 +381,7 @@ append_header_names(LibBalsaCondition *cond, GString *res)
         { CONDITION_MATCH_TO, N_("To") },
         { CONDITION_MATCH_FROM, N_("From") },
         { CONDITION_MATCH_SUBJECT, N_("Subject") },
-        { CONDITION_MATCH_CC, N_("Cc") },
+        { CONDITION_MATCH_CC, N_("CC") },
         { CONDITION_MATCH_BODY, N_("Body") }
     };
 
@@ -496,11 +494,7 @@ libbalsa_condition_regex_free(LibBalsaConditionRegex* reg, gpointer throwaway)
 
     g_free(reg->string);
     if (reg->compiled) 
-#if USE_GREGEX
         g_regex_unref(reg->compiled);
-#else                           /* USE_GREGEX */
-	regfree(reg->compiled);
-#endif                          /* USE_GREGEX */
 }				/* end condition_regex_free() */
 
 void 
