@@ -268,9 +268,9 @@ libbalsa_cert_subject_readable(const gchar *subject)
         if (equals) {
             *equals++ = '\0';
             for (ldap_elem = ldap_id_list;
-                 ldap_elem->ldap_id && strcmp(ldap_elem->ldap_id, elements[n]);
+                 g_strcmp0(ldap_elem->ldap_id, elements[n]) != 0;
                  ldap_elem++);
-            if (ldap_elem->ldap_id)
+            if (ldap_elem->ldap_id != NULL)
                 result = g_string_append(result, ldap_elem->readable);
             else
                 result = g_string_append(result, elements[n]);
