@@ -62,6 +62,8 @@
 static SSL_CTX *global_ssl_context = NULL;
 static GMutex global_tls_lock;
 
+  /* Setting callbacks is not required any more with 1.1.0-pre4 and newer */
+#if OPENSSL_VERSION_NUMBER < 0x010100004L
 /* OpenSSL static locks */
 static GMutex *mutexes = NULL;
 
@@ -153,6 +155,9 @@ imaptls_thread_cleanup(void)
   return 1;
 }
 #endif /* DO_PROPER_OPENSSL_CLEANUP */
+#else
+static int imaptls_thread_setup() { return 0; }
+#endif /* OPENSSL_VERSION_NUMBER < OPENSSL_VER(1,1,0,0,4) */
 
 SSL*
 imap_create_ssl(void)
@@ -172,6 +177,14 @@ imap_create_ssl(void)
     /* Note: SSLv23_client_method() actually enables *all* protocols, including
      * SSLv(2|3) and TLSv1.(0|1|2), so we must switch all unsafe ones off */
     global_ssl_context = SSL_CTX_new (SSLv23_client_method ());
+    if(!global_ssl_context) {
+        fprintf(stderr, "Could not initialize SSL Context.\n");
+        ERR_print_errors_fp(stderr);
+        fprintf(stderr, "\nEnd of print_errors\n");
+        g_mutex_unlock(&global_tls_lock);
+        return NULL;
+    }
+
 #ifdef ENABLE_SSL3
     SSL_CTX_set_options(global_ssl_context, SSL_OP_ALL|SSL_OP_NO_SSLv2);
 #else
@@ -244,12 +257,12 @@ imap_check_server_identity(SSL *ssl, const char *host,
     int i;
 
     for (i=0; i< sk_GENERAL_NAME_num(altnames); i++) {
-      const GENERAL_NAME *name = sk_GENERAL_NAME_value(altnames, i);
+      const GENERAL_NAME *current_name = sk_GENERAL_NAME_value(altnames, i);
 
       /* We handle only GEN_DNS. GEN_IP (certificates for IP numbers)
          are too weird to be real in IMAP case. */
-      if (name->type == GEN_DNS) {
-        const ASN1_IA5STRING *ia5 = name->d.ia5;
+      if (current_name->type == GEN_DNS) {
+        const ASN1_IA5STRING *ia5 = current_name->d.ia5;
         const char *name = (const char*)ia5->data;
         has_extension_with_dns_name = 1;
 
