@@ -22,10 +22,6 @@ void imap_unquote_string(char *s);
 char* imap_next_word(char *s);
 char* imap_skip_atom(char *s);
 
-void lit_conv_to_base64(char *out, const char *in, 
-                        size_t len, size_t olen);
-int lit_conv_from_base64(char *out, const char *in);
-
 char* imap_mailbox_to_utf8(const char *src);
 char* imap_utf8_to_mailbox(const char *src);
 
