@@ -41,6 +41,7 @@ typedef struct {
     gchar *path;
     guint changes;
     time_t mtime;
+    gboolean private;
 } LibBalsaConf;
 
 static LibBalsaConf lbc_conf;
@@ -77,12 +78,13 @@ lbc_readfile(const gchar * filename)
 
 static void
 lbc_init(LibBalsaConf * conf, const gchar * filename,
-         const gchar * old_dir)
+         const gchar * old_dir, gboolean private)
 {
     struct stat buf;
     GError *error = NULL;
     gint rc;
 
+    conf->private = private;
     if (!conf->path)
         conf->path =
             g_build_filename(g_get_home_dir(), ".balsa", filename, NULL);
@@ -104,7 +106,7 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
     if (!g_key_file_load_from_file
         (conf->key_file, conf->path, G_KEY_FILE_NONE, &error)) {
         gchar *old_path;
-        gchar *buf;
+        gchar *key_file_text;
         static gboolean warn = TRUE;
 
         old_path =
@@ -115,18 +117,18 @@ lbc_init(LibBalsaConf * conf, const gchar * filename,
 #endif                          /* DEBUG */
         g_clear_error(&error);
 
-        buf = lbc_readfile(old_path);
-        if (buf) {
+        key_file_text = lbc_readfile(old_path);
+        if (key_file_text != NULL) {
             /* GnomeConfig used ' ' as the list separator... */
             g_key_file_set_list_separator(conf->key_file, ' ');
-            g_key_file_load_from_data(conf->key_file, buf, -1,
+            g_key_file_load_from_data(conf->key_file, key_file_text, -1,
                                       G_KEY_FILE_KEEP_COMMENTS, &error);
-            g_free(buf);
+            g_free(key_file_text);
             /* ...but GKeyFile doesn't handle it properly, so we'll
              * revert to the default ';'. */
             g_key_file_set_list_separator(conf->key_file, ';');
         }
-        if (!buf || error) {
+        if (key_file_text == NULL || error != NULL) {
 #if DEBUG
             g_message("Could not load key file from file “%s”: %s",
                       old_path,
@@ -153,8 +155,8 @@ lbc_lock(void)
 
     g_rec_mutex_lock(&lbc_mutex);
     if (!initialized) {
-        lbc_init(&lbc_conf, "config", ".gnome2");
-        lbc_init(&lbc_conf_priv, "config-private", ".gnome2_private");
+        lbc_init(&lbc_conf, "config", ".gnome2", FALSE);
+        lbc_init(&lbc_conf_priv, "config-private", ".gnome2_private", TRUE);
         initialized = TRUE;
     }
 }
@@ -511,6 +513,8 @@ lbc_sync(LibBalsaConf * conf)
                           " changes not saved", conf->path);
 #endif                          /* DEBUG */
         }
+    } else if (conf->private) {
+        g_chmod(conf->path, 0600);
     }
 
     g_free(buf);
