@@ -28,8 +28,6 @@
 #include <gdk/gdk.h>
 #include <gmime/gmime.h>
 
-#include "libbalsa.h"
-
 #define LIBBALSA_TYPE_MAILBOX \
     (libbalsa_mailbox_get_type())
 #define LIBBALSA_MAILBOX(obj) \
@@ -68,8 +66,6 @@ do {\
     }\
 } while (0)
 
-#define LIBBALSA_MAILBOX_UNTHREADED "libbalsa-mailbox-unthreaded"
-
 
 typedef enum {
     LB_MAILBOX_SORT_NO, /* == NATURAL */
@@ -94,12 +90,9 @@ typedef enum {
 } LibBalsaMailboxSortType;
 
 typedef enum {
-    LIBBALSA_NTFY_SOURCE,
-    LIBBALSA_NTFY_FINISHED,
-    LIBBALSA_NTFY_MSGINFO,
-    LIBBALSA_NTFY_PROGRESS,
-    LIBBALSA_NTFY_UPDATECONFIG,
-    LIBBALSA_NTFY_ERROR
+	LIBBALSA_NTFY_INIT,
+	LIBBALSA_NTFY_UPDATE,
+	LIBBALSA_NTFY_FINISHED
 } LibBalsaMailboxNotify;
 
 
@@ -251,6 +244,7 @@ struct _LibBalsaMailbox {
 
     guint changed_idle_id;
     guint queue_check_idle_id;
+    guint need_threading_idle_id;
 };
 
 /* Search iter */
@@ -275,8 +269,7 @@ struct _LibBalsaMailboxClass {
     /* Signals */
     void (*changed) (LibBalsaMailbox * mailbox);
     void (*message_expunged) (LibBalsaMailbox * mailbox, guint seqno);
-    void (*progress_notify) (LibBalsaMailbox * mailbox, int type,
-                             int prog, int tot, const gchar* msg);
+    void (*progress_notify) (LibBalsaMailbox * mailbox, gint action, gdouble fraction, gchar *message);
 
     /* Virtual Functions */
     gboolean (*open_mailbox) (LibBalsaMailbox * mailbox, GError **err);
@@ -332,6 +325,9 @@ struct _LibBalsaMailboxClass {
     guint (*total_messages)(LibBalsaMailbox * mailbox);
     GArray *(*duplicate_msgnos) (LibBalsaMailbox * mailbox);
     void (*lock_store) (LibBalsaMailbox * mailbox, gboolean lock);
+    void (*test_can_reach) (LibBalsaMailbox          * mailbox,
+                            LibBalsaCanReachCallback * cb,
+                            gpointer                   cb_data);
 };
 
 GType libbalsa_mailbox_get_type(void);
@@ -351,9 +347,12 @@ void libbalsa_mailbox_check(LibBalsaMailbox * mailbox);
 void libbalsa_mailbox_changed(LibBalsaMailbox * mailbox);
 void libbalsa_mailbox_set_unread_messages_flag(LibBalsaMailbox * mailbox,
 					       gboolean has_unread);
-void libbalsa_mailbox_progress_notify(LibBalsaMailbox * mailbox,
-                                      int type, int prog, int tot,
-                                      const gchar* msg);
+void libbalsa_mailbox_progress_notify(LibBalsaMailbox       *mailbox,
+									  LibBalsaMailboxNotify  action,
+									  gdouble		         fraction,
+									  const gchar           *message,
+									  ...)
+	G_GNUC_PRINTF(4, 5);
 
 /** Message access functions.
  */
@@ -648,6 +647,11 @@ void libbalsa_mailbox_set_background(LibBalsaMailbox * mailbox,
 void libbalsa_mailbox_lock_store  (LibBalsaMailbox * mailbox);
 void libbalsa_mailbox_unlock_store(LibBalsaMailbox * mailbox);
 
+/* Check whether a mailbox can be reached */
+void libbalsa_mailbox_test_can_reach(LibBalsaMailbox          * mailbox,
+                                     LibBalsaCanReachCallback * cb,
+                                     gpointer                   cb_data);
+
 /* columns ids */
 typedef enum {
     LB_MBOX_MSGNO_COL,
@@ -666,6 +670,6 @@ typedef enum {
     LB_MBOX_N_COLS
 } LibBalsaMailboxColumn;
 
-extern gchar *libbalsa_mailbox_date_format;
+extern gchar **libbalsa_mailbox_date_format;
 
 #endif				/* __LIBBALSA_MAILBOX_H__ */
