@@ -103,6 +103,9 @@ static gboolean libbalsa_mailbox_local_msgno_has_flags(LibBalsaMailbox *
                                                        set,
                                                        LibBalsaMessageFlag
                                                        unset);
+static void libbalsa_mailbox_local_test_can_reach(LibBalsaMailbox          * mailbox,
+                                                  LibBalsaCanReachCallback * cb,
+                                                  gpointer                   cb_data);
 
 /* LibBalsaMailboxLocal class method: */
 static void lbm_local_real_remove_files(LibBalsaMailboxLocal * local);
@@ -181,6 +184,8 @@ libbalsa_mailbox_local_class_init(LibBalsaMailboxLocalClass * klass)
         libbalsa_mailbox_local_msgno_has_flags;
     libbalsa_mailbox_class->duplicate_msgnos =
         libbalsa_mailbox_local_duplicate_msgnos;
+    libbalsa_mailbox_class->test_can_reach =
+        libbalsa_mailbox_local_test_can_reach;
     klass->check_files  = NULL;
     klass->set_path     = NULL;
     klass->remove_files = lbm_local_real_remove_files;
@@ -229,12 +234,14 @@ libbalsa_mailbox_local_set_path(LibBalsaMailboxLocal * mailbox,
                                 const gchar * path, gboolean create)
 {
     int i;
-    LibBalsaMailboxLocalClass *klass =
-        LIBBALSA_MAILBOX_LOCAL_GET_CLASS(mailbox);
+    LibBalsaMailboxLocalClass *klass;
 
     g_return_val_if_fail(LIBBALSA_IS_MAILBOX_LOCAL(mailbox), -1);
     g_return_val_if_fail(path != NULL, -1);
 
+    klass = LIBBALSA_MAILBOX_LOCAL_GET_CLASS(mailbox);
+    g_assert(klass != NULL);
+
     if (LIBBALSA_MAILBOX(mailbox)->url != NULL) {
         const gchar *cur_path = libbalsa_mailbox_local_get_path(mailbox);
         if (strcmp(path, cur_path) == 0)
@@ -630,8 +637,6 @@ lbm_local_restore_tree(LibBalsaMailboxLocal * local, guint * total)
     }
     *total = info->value.total;
 
-    gdk_threads_enter();
-
     seen = g_new0(guint8, *total);
     parent = mailbox->msg_tree;
     sibling = NULL;
@@ -646,7 +651,6 @@ lbm_local_restore_tree(LibBalsaMailboxLocal * local, guint * total)
             g_free(seen);
             g_free(contents);
             g_free(name);
-            gdk_threads_leave();
             return FALSE;
         }
         seen[info->msgno - 1] = TRUE;
@@ -670,7 +674,6 @@ lbm_local_restore_tree(LibBalsaMailboxLocal * local, guint * total)
                     g_free(seen);
                     g_free(contents);
                     g_free(name);
-    		    gdk_threads_leave();
                     return FALSE;
                 }
             }
@@ -696,8 +699,6 @@ lbm_local_restore_tree(LibBalsaMailboxLocal * local, guint * total)
     g_free(contents);
     g_free(name);
 
-    gdk_threads_leave();
-
     return TRUE;
 }
 
@@ -1044,16 +1045,15 @@ lbml_load_messages_idle_cb(LibBalsaMailbox * mailbox)
                                                   guint);
 
     libbalsa_lock_mailbox(mailbox);
-    gdk_threads_enter();
+    local = (LibBalsaMailboxLocal *) mailbox;
+    local->load_messages_id = 0;
 
     if (!mailbox->msg_tree) {
 	/* Mailbox is closed, or no view has been created. */
-        gdk_threads_leave();
         libbalsa_unlock_mailbox(mailbox);
 	return FALSE;
     }
 
-    local = (LibBalsaMailboxLocal *) mailbox;
     lastno = libbalsa_mailbox_total_messages(mailbox);
     msgno = local->msgno;
     new_messages = lastno - msgno;
@@ -1069,8 +1069,6 @@ lbml_load_messages_idle_cb(LibBalsaMailbox * mailbox)
                                                  msg_info->message);
     }
 
-    gdk_threads_leave();
-
     if (new_messages) {
 	libbalsa_mailbox_run_filters_on_reception(mailbox);
 	libbalsa_mailbox_set_unread_messages_flag(mailbox,
@@ -1078,7 +1076,6 @@ lbml_load_messages_idle_cb(LibBalsaMailbox * mailbox)
 						  unread_messages > 0);
     }
 
-    local->load_messages_id = 0;
     libbalsa_unlock_mailbox(mailbox);
     return FALSE;
 }
@@ -1193,11 +1190,9 @@ libbalsa_mailbox_local_set_threading(LibBalsaMailbox * mailbox,
         info = g_slice_new(LbmlSetThreadingInfo);
         info->mailbox = g_object_ref(mailbox);
         info->thread_type = thread_type;
-        gdk_threads_add_idle((GSourceFunc) lbml_set_threading_idle_cb, info);
+        g_idle_add((GSourceFunc) lbml_set_threading_idle_cb, info);
     } else {
-        gdk_threads_enter();
         lbml_set_threading(mailbox, thread_type);
-        gdk_threads_leave();
     }
 #if defined(DEBUG_LOADING_AND_THREADING)
     printf("after threading time=%lu\n", (unsigned long) time(NULL));
@@ -1349,8 +1344,6 @@ libbalsa_mailbox_local_prepare_threading(LibBalsaMailbox * mailbox,
     libbalsa_progress_set_text(&progress, NULL, 0);
 
     if (retval && need_thread && !local->thread_id) {
-        LibBalsaMailbox *mailbox = LIBBALSA_MAILBOX(local);
-
         if (libbalsa_mailbox_get_threading_type(mailbox) !=
             LB_MAILBOX_THREADING_FLAT
             || libbalsa_mailbox_get_sort_field(mailbox) !=
@@ -1444,7 +1437,6 @@ struct _ThreadingInfo {
     GNode *root;
     GHashTable *id_table;
     GHashTable *subject_table;
-    GSList *unthreaded;
     LibBalsaMailboxThreadingType type;
 };
 typedef struct _ThreadingInfo ThreadingInfo;
@@ -1471,8 +1463,6 @@ lbml_info_setup(LibBalsaMailbox * mailbox, ThreadingInfo * ti)
     ti->root = g_node_new(mailbox->msg_tree);
     ti->id_table = g_hash_table_new(g_str_hash, g_str_equal);
     ti->subject_table = NULL;
-    ti->unthreaded =
-        g_object_get_data(G_OBJECT(mailbox), LIBBALSA_MAILBOX_UNTHREADED);
 }
 
 static void
@@ -2359,6 +2349,14 @@ libbalsa_mailbox_local_duplicate_msgnos(LibBalsaMailbox * mailbox)
     return msgnos;
 }
 
+static void
+libbalsa_mailbox_local_test_can_reach(LibBalsaMailbox          * mailbox,
+                                      LibBalsaCanReachCallback * cb,
+                                      gpointer                   cb_data)
+{
+    cb((GObject *) mailbox, TRUE, cb_data);
+}
+
 /* LibBalsaMailboxLocal class method: */
 static void
 lbm_local_real_remove_files(LibBalsaMailboxLocal * local)
