@@ -29,7 +29,6 @@
 
 #define _SVID_SOURCE           1
 #include <ctype.h>
-#include <dirent.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -43,25 +42,13 @@
 #include "libbalsa_private.h"
 #include "html.h"
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 
 static const gchar *libbalsa_get_codeset_name(const gchar *txt, 
 					      LibBalsaCodeset Codeset);
+#ifndef HAVE_STRUCT_UTSNAME_DOMAINNAME
 static int getdnsdomainname(char *s, size_t l);
 
-gchar *
-libbalsa_get_hostname(void)
-{
-    struct utsname utsname;
-    gchar *p;
-    uname(&utsname);
-
-    /* Some systems return Fqdn rather than just the hostname */
-    if ((p = strchr (utsname.nodename, '.')))
-	*p = 0;
-
-    return g_strdup (utsname.nodename);
-}
-
 static int 
 getdnsdomainname (char *s, size_t l)
 {
@@ -109,12 +96,19 @@ getdnsdomainname (char *s, size_t l)
   fclose (f);
   return (-1);
 }
+#endif                          /* !HAVE_STRUCT_UTSNAME_DOMAINNAME */
 
 gchar *
 libbalsa_get_domainname(void)
 {
-    char domainname[256]; /* arbitrary length */
     struct utsname utsname;
+#ifdef HAVE_STRUCT_UTSNAME_DOMAINNAME
+
+    uname(&utsname);
+
+    return g_strdup(utsname.domainname);
+#else                           /* HAVE_STRUCT_UTSNAME_DOMAINNAME */
+    char domainname[256]; /* arbitrary length */
     gchar *d;
  
     uname(&utsname);
@@ -127,160 +121,7 @@ libbalsa_get_domainname(void)
 	return g_strdup(domainname);
     }
     return NULL;
-}
-
-/* libbalsa_urlencode: 
- * Taken from PHP's urlencode()
- */
-gchar*
-libbalsa_urlencode(const gchar* str)
-{
-    static const unsigned char hexchars[] = "0123456789ABCDEF";
-    gchar *retval = NULL;
-    gchar *x = NULL;
-    
-    g_return_val_if_fail(str != NULL, NULL);
-    
-    retval = malloc(strlen(str) * 3 + 1);
-    
-    for (x = retval; *str != '\0'; str++, x++) {
-       *x = *str;
-       if (*x == ' ') {
-           *x = '+';
-       } else if (!isalnum(*x) && strchr("_-.", *x) == NULL) {
-           /* Allow only alnum chars and '_', '-', '.'; escape the rest */
-           *x++ = '%';
-           *x++ = hexchars[(*str >> 4) & 0x0F];
-           *x = hexchars[(*str) & 0x0F];
-       }
-    }
-    
-    *x = '\0';
-    return retval;
-}
-
-gchar *
-libbalsa_urldecode(const gchar * str)
-{
-    gchar *retval;
-    gchar *x;
-
-    retval = g_new(char, strlen(str)+1);
-
-    for (x = retval; *str != '\0'; str++, x++) {
-	*x = *str;
-	if (*x == '+')
-	    *x = ' ';
-	else if (*x == '%') {
-	    if (!*++str || !g_ascii_isxdigit(*str))
-		break;
-	    *x = g_ascii_xdigit_value(*str);
-	    if (!*++str || !g_ascii_isxdigit(*str))
-		break;
-	    *x = *x << 4 | g_ascii_xdigit_value(*str);
-	}
-    }
-
-    *x = '\0';
-    return retval;
-}
-
-/* readfile allocates enough space for the ending '\0' characeter as well.
-   returns the number of read characters.
-*/
-size_t libbalsa_readfile(FILE * fp, char **buf)
-{
-    size_t size;
-    off_t offset;
-    int r;
-    int fd;
-    struct stat statbuf;
-
-    *buf = NULL;
-    if (!fp)
-	return 0;
-
-    fd = fileno(fp);
-    if (fstat(fd, &statbuf) == -1)
-	return -1;
-
-    size = statbuf.st_size;
-
-    if (!size) {
-	*buf = NULL;
-	return size;
-    }
-
-    lseek(fd, 0, SEEK_SET);
-
-    *buf = (char *) g_malloc(size + 1);
-    if (*buf == NULL)
-	return -1;
-
-    offset = 0;
-    while ((size_t)offset < size) {
-	r = read(fd, *buf + offset, size - offset);
-	if (r == 0) { /* proper EOF */
-            (*buf)[offset] = '\0';
-	    return offset;
-        }
-	if (r > 0) {
-	    offset += r;
-	} else if ((errno != EAGAIN) && (errno != EINTR)) {
-	    perror("Error reading file:");
-            (*buf)[offset] = '\0';
-	    return -1;
-	}
-    }
-    (*buf)[size] = '\0';
-
-    return size;
-}
-
-/* readfile_nostat is identical to readfile except it reads to EOF.
-   This enables the use of pipes to programs for such things as
-   the signature file.
-*/
-size_t libbalsa_readfile_nostat(FILE * fp, char **buf)
-{
-    size_t size;
-    GString *gstr;
-    char rbuf[512];
-    size_t rlen = 512;
-    int r;
-    int fd;
-
-    *buf = NULL;
-    fd = fileno(fp);
-    if (!fp)
-	return 0;
-
-    r = read(fd, rbuf, rlen-1);
-    if (r <= 0)
-	return 0;
-
-    rbuf[r] = '\0';
-    gstr = g_string_new(rbuf);
-
-    do {
-	if ((r = read(fd, rbuf, rlen-1)) != 0) {
-	    /* chbm: if your sig is larger than 512 you deserve this */
-	    if ((r < 0) && (errno != EAGAIN) && (errno != EINTR)) {
-		perror("Error reading file:");
-		g_string_free(gstr, TRUE);
-		return -1;
-	    };
-	    if (r > 0) {
-		rbuf[r] = '\0';	
-		g_string_append(gstr,rbuf);
-	    }
-	}
-    } while( r != 0 );
-
-    size = gstr->len;
-    *buf = g_string_free(gstr, FALSE);
-
-    return size;
+#endif                          /* HAVE_STRUCT_UTSNAME_DOMAINNAME */
 }
 
 /* libbalsa_find_word:
@@ -359,74 +200,39 @@ libbalsa_wrap_string(gchar * str, int width)
 gboolean
 libbalsa_delete_directory_contents(const gchar *path)
 {
-    struct stat sb;
-    DIR *d;
-    struct dirent *de;
-    gchar *new_path;
+	GDir *dir;
+	gboolean result;
 
-    d = opendir(path);
-    g_return_val_if_fail(d, FALSE);
+    g_return_val_if_fail(path != NULL, FALSE);
+    dir = g_dir_open(path, 0, NULL);
+    if (dir == NULL) {
+    	result = FALSE;
+    } else {
+    	const gchar *item;
 
-    for (de = readdir(d); de; de = readdir(d)) {
-	if (strcmp(de->d_name, ".") == 0 ||
-	    strcmp(de->d_name, "..") == 0)
-	    continue;
-	new_path = g_strdup_printf("%s/%s", path, de->d_name);
+    	result = TRUE;
+    	item = g_dir_read_name(dir);
+    	while (result && (item != NULL)) {
+    		gchar *full_path;
 
-	stat(new_path, &sb);
-	if (S_ISDIR(sb.st_mode)) {
-	    if (!libbalsa_delete_directory_contents(new_path) ||
-		rmdir(new_path) == -1) {
-		g_free(new_path);
-		closedir(d);
-		return FALSE;
-	    }
-	} else {
-	    if (unlink( new_path ) == -1) {
-		g_free(new_path);
-		closedir(d);
-		return FALSE;
-	    }
-	}
-	g_free(new_path);
-	new_path = 0;
+    		full_path = g_build_filename(path, item, NULL);
+    		if (g_file_test(full_path, G_FILE_TEST_IS_DIR)) {
+    	   		result = libbalsa_delete_directory_contents(full_path);
+    			if (g_rmdir(full_path) != 0) {
+    				result = FALSE;
+    			}
+    		} else {
+    	   		if (g_unlink(full_path) != 0) {
+    				result = FALSE;
+    			}
+    		}
+    		g_free(full_path);
+    		item = g_dir_read_name(dir);
+    	}
+    	g_dir_close(dir);
     }
 
-    closedir(d);
-    return TRUE;
-}
-
-/* libbalsa_truncate_string
- *
- * Arguments:
- *   str    the string to be truncated;
- *   length truncation length;
- *   dots   the number of trailing dots to be used to indicate
- *          truncation.
- *
- * Value:
- *   pointer to a newly allocated string; free with `g_free' when it's
- *   no longer needed.
- */
-gchar *
-libbalsa_truncate_string(const gchar *str, gint length, gint dots)
-{
-    gchar *res;
-    gchar *p;
-
-    if (str == NULL)
-        return NULL;
-
-    if (length <= 0 || strlen(str) <= (guint) length)
-        return g_strdup(str);
-
-    res = g_strndup(str, length);
-
-    p = res + length - dots;
-    while (--dots >= 0)
-        *p++ = '.';
-
-    return res;
+    return result;
 }
 
 /* libbalsa_expand_path:
@@ -453,29 +259,9 @@ libbalsa_expand_path(const gchar * path)
 gboolean 
 libbalsa_mktempdir (char **s)
 {
-    gchar *name;
-    int fd;
-
     g_return_val_if_fail(s != NULL, FALSE);
-
-    do {
-	GError *error = NULL;
-	fd = g_file_open_tmp("balsa-tmpdir-XXXXXX", &name, &error);
-	close(fd);
-	unlink(name);
-	/* Here is a short time that the name could be reused */
-	fd = mkdir(name, 0700);
-	if (fd == -1) {
-	    g_free(name);
-	    if (!g_error_matches(error, G_FILE_ERROR, G_FILE_ERROR_EXIST))
-		return FALSE;
-	}
-	if (error)
-	    g_error_free(error);
-    } while (fd == -1);
-    *s = name;
-    /* FIXME: rmdir(name) at sometime */
-    return TRUE;
+    *s = g_build_filename(g_get_tmp_dir(), "balsa-tmpdir-XXXXXX", NULL);
+    return g_mkdtemp_full(*s, 0700) != NULL;
 }
 
 /* libbalsa_set_fallback_codeset: sets the codeset for incorrectly
@@ -1226,11 +1012,6 @@ qualified_hostname(const char *name)
 }
 
 
-gchar *libbalsa_guess_pop_server()
-{
-    return qualified_hostname(POP_SERVER);
-}
-
 gchar *libbalsa_guess_imap_server()
 {
     return qualified_hostname(IMAP_SERVER);
@@ -1290,32 +1071,6 @@ gchar *libbalsa_guess_ldap_name()
     return NULL;
 }
 
-gchar *libbalsa_guess_ldif_file()
-{
-    int i;
-    gchar *ldif;
-
-    static const gchar *guesses[] = {
-	"address.ldif",
-	".address.ldif",
-	"address-book.ldif",
-	".address-book.ldif",
-	".addressbook.ldif",
-	NULL
-    };
-
-    for (i = 0; guesses[i] != NULL; i++) {
-	ldif =  g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, 
-			    guesses[i], NULL);
-	if (g_file_test(ldif, G_FILE_TEST_EXISTS))
-	     return ldif;
-	  
-	g_free(ldif);
-    }
-    return g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, 
-			guesses[i], NULL); /* *** Or NULL */
-    
-}
 
 gboolean
 libbalsa_path_is_below_dir(const gchar * path, const gchar * dir)
