@@ -91,13 +91,9 @@ GtkWidget *libbalsa_charset_button_new(void);
 LibBalsaTextAttribute libbalsa_text_attr_string(const gchar * string);
 LibBalsaTextAttribute libbalsa_text_attr_file(const gchar * filename);
 
-size_t libbalsa_readfile(FILE * fp, char **buf);
-size_t libbalsa_readfile_nostat(FILE * fp, char **buf);
-
-gchar *libbalsa_get_hostname(void);
 gchar *libbalsa_get_domainname(void);
-gchar *libbalsa_urlencode(const gchar* str);
-gchar *libbalsa_urldecode(const gchar * str);
+#define libbalsa_urlencode(str) (g_uri_escape_string((str), NULL, FALSE))
+#define libbalsa_urldecode(str) (g_uri_unescape_string((str), NULL))
 
 gboolean libbalsa_find_word(const gchar * word, const gchar * str);
 void libbalsa_wrap_string(gchar * str, int width);
@@ -112,13 +108,8 @@ void libbalsa_wrap_view(GtkTextView * view, gint length);
 void libbalsa_unwrap_buffer(GtkTextBuffer * buffer, GtkTextIter * iter,
                             gint lines);
 
-const char* libbalsa_set_charset(const gchar * charset);
-const char* libbalsa_set_send_charset(const gchar * charset);
-
 gboolean libbalsa_delete_directory_contents(const gchar *path);
-gchar *libbalsa_truncate_string(const gchar * str, gint length, gint dots);
 gchar *libbalsa_expand_path(const gchar *path);
-void libbalsa_contract_path(gchar *path);
 gboolean libbalsa_mktempdir(gchar ** name);
 LibBalsaCodeset libbalsa_set_fallback_codeset(LibBalsaCodeset codeset);
 gboolean libbalsa_utf8_sanitize(gchar ** text, gboolean fallback,
@@ -157,8 +148,6 @@ void libbalsa_assure_balsa_dir(void);
 gchar *libbalsa_guess_ldap_base(void);
 gchar *libbalsa_guess_ldap_name(void);
 
-gchar *libbalsa_guess_ldif_file(void);
-
 gboolean libbalsa_ldap_exists(const gchar *server);
 
 gboolean libbalsa_path_is_below_dir(const gchar * path, const gchar * dir);
