@@ -28,8 +28,6 @@
 
 #if defined(HAVE_LIBSECRET)
 #include <libsecret/secret.h>
-#elif defined(HAVE_GNOME_KEYRING)
-#include <gnome-keyring.h>
 #endif                          /* defined(HAVE_LIBSECRET) */
 
 #include <openssl/err.h>
@@ -51,18 +49,6 @@ static const SecretSchema server_schema = {
     }
 };
 const SecretSchema *LIBBALSA_SERVER_SECRET_SCHEMA = &server_schema;
-#elif defined(HAVE_GNOME_KEYRING) && !defined(HAVE_GNOME_KEYRING_24)
-static const GnomeKeyringPasswordSchema server_schema = {
-    GNOME_KEYRING_ITEM_GENERIC_SECRET,
-    {
-	{ "protocol", GNOME_KEYRING_ATTRIBUTE_TYPE_STRING },
-	{ "server",   GNOME_KEYRING_ATTRIBUTE_TYPE_STRING },
-	{ "user",     GNOME_KEYRING_ATTRIBUTE_TYPE_STRING },
-	{ NULL, 0 }
-    }
-};
-const GnomeKeyringPasswordSchema* LIBBALSA_SERVER_KEYRING_SCHEMA =
-    &server_schema;
 #endif                          /* defined(HAVE_LIBSECRET) */
 
 static GObjectClass *parent_class = NULL;
@@ -182,6 +168,7 @@ libbalsa_server_init(LibBalsaServer * server)
     server->remember_passwd = TRUE;
     server->use_ssl         = FALSE;
     server->tls_mode        = LIBBALSA_TLS_ENABLED;
+    server->security		= NET_CLIENT_CRYPT_STARTTLS;
 }
 
 /* leave object in sane state (NULLified fields) */
@@ -196,8 +183,19 @@ libbalsa_server_finalize(GObject * object)
 
     g_free(server->host);   server->host = NULL;
     g_free(server->user);   server->user = NULL;
+    if (server->passwd != NULL) {
+    	memset(server->passwd, 0, strlen(server->passwd));
+    }
     libbalsa_free_password(server->passwd); server->passwd = NULL;
 
+    g_free(server->cert_file);
+    server->cert_file = NULL;
+    if (server->cert_passphrase != NULL) {
+    	memset(server->cert_passphrase, 0, strlen(server->cert_passphrase));
+    }
+    g_free(server->cert_passphrase);
+    server->cert_passphrase = NULL;
+
     G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
@@ -324,9 +322,14 @@ libbalsa_server_load_config(LibBalsaServer * server)
         }
     }       
     server->use_ssl = libbalsa_conf_get_bool("SSL=false");
-    d=0;
+    d = FALSE;
     server->tls_mode = libbalsa_conf_get_int_with_default("TLSMode", &d);
     if(d) server->tls_mode = LIBBALSA_TLS_ENABLED;
+    d = FALSE;
+    server->security = libbalsa_conf_get_int_with_default("Security", &d);
+    if (d) {
+    	server->security = NET_CLIENT_CRYPT_STARTTLS;
+    }
     server->user = libbalsa_conf_private_get_string("Username");
     if (!server->user)
 	server->user = g_strdup(getenv("USER"));
@@ -374,35 +377,6 @@ libbalsa_server_load_config(LibBalsaServer * server)
                 }
             }
         }
-#elif defined (HAVE_GNOME_KEYRING)
-	GnomeKeyringResult res =
-	    gnome_keyring_find_password_sync(LIBBALSA_SERVER_KEYRING_SCHEMA,
-					     &server->passwd,
-					     "protocol", server->protocol,
-					     "server", server->host,
-					     "user", server->user,
-					     NULL);
-	if(res != GNOME_KEYRING_RESULT_OK) {
-	    gnome_keyring_free_password(server->passwd);
-	    server->passwd = NULL;
-	    printf("Error retrieving password from key ring. Falling back\n");
-	    server->passwd = libbalsa_conf_private_get_string("Password");
-	    if (server->passwd != NULL) {
-		gchar *buff = libbalsa_rot(server->passwd);
-		libbalsa_free_password(server->passwd);
-		server->passwd = buff;
-		gnome_keyring_store_password_sync
-		    (LIBBALSA_SERVER_KEYRING_SCHEMA, NULL,
-		     _("Balsa passwords"), server->passwd,
-		     "protocol", server->protocol,
-		     "server", server->host,
-		     "user", server->user,
-		     NULL);
-		    /* We could in principle clear the password in the
-		       config file here but we do not for the backward
-		       compatibility. */
-	    }
-	}
 #else
 	server->passwd = libbalsa_conf_private_get_string("Password");
 	if (server->passwd != NULL) {
@@ -416,6 +390,19 @@ libbalsa_server_load_config(LibBalsaServer * server)
 	libbalsa_free_password(server->passwd);
 	server->passwd = NULL;
     }
+
+    server->client_cert = libbalsa_conf_get_bool("NeedClientCert=false");
+    server->cert_file = libbalsa_conf_get_string("UserCertificateFile");
+    server->cert_passphrase = libbalsa_conf_private_get_string("CertificatePassphrase");
+    if ((server->cert_passphrase != NULL) && (server->cert_passphrase[0] != '\0')) {
+        gchar *tmp = libbalsa_rot(server->cert_passphrase);
+
+        g_free(server->cert_passphrase);
+        server->cert_passphrase = tmp;
+    } else {
+    	g_free(server->cert_passphrase);
+    	server->cert_passphrase = NULL;
+    }
 }
 
 /* libbalsa_server_save_config:
@@ -449,23 +436,27 @@ libbalsa_server_save_config(LibBalsaServer * server)
                    server->user, server->host, err->message);
             g_error_free(err);
         }
-#elif defined (HAVE_GNOME_KEYRING)
-	gnome_keyring_store_password_sync(LIBBALSA_SERVER_KEYRING_SCHEMA,
-				     NULL,
-				     _("Balsa passwords"),
-				     server->passwd,
-				     "protocol", server->protocol,
-				     "server", server->host,
-				     "user", server->user,
-				     NULL);
 #else
 	gchar *buff = libbalsa_rot(server->passwd);
 	libbalsa_conf_private_set_string("Password", buff);
 	g_free(buff);
 #endif                          /* defined(HAVE_LIBSECRET) */
     }
+
+    libbalsa_conf_set_bool("NeedClientCert", server->client_cert);
+    if (server->cert_file != NULL) {
+    	libbalsa_conf_set_string("UserCertificateFile", server->cert_file);
+    }
+    if (server->cert_passphrase != NULL) {
+        gchar *tmp = libbalsa_rot(server->cert_passphrase);
+
+        libbalsa_conf_private_set_string("CertificatePassphrase", tmp);
+        g_free(tmp);
+    }
+
     libbalsa_conf_set_bool("SSL", server->use_ssl);
     libbalsa_conf_set_int("TLSMode", server->tls_mode);
+    libbalsa_conf_set_int("Security", server->security);
 }
 
 void
@@ -558,3 +549,153 @@ libbalsa_server_connect_signals(LibBalsaServer * server, GCallback cb,
                                       [GET_PASSWORD], 0, TRUE))
         g_signal_connect(server, "get-password", cb, cb_data);
 }
+
+
+gchar **
+libbalsa_server_get_auth(NetClient *client,
+						 gboolean   need_passwd,
+         	 	 	 	 gpointer   user_data)
+{
+    LibBalsaServer *server = LIBBALSA_SERVER(user_data);
+    gchar **result = NULL;
+
+    g_debug("%s: %p %p: encrypted = %d", __func__, client, user_data,
+            net_client_is_encrypted(client));
+    if (server->try_anonymous == 0U) {
+        result = g_new0(gchar *, 3U);
+        result[0] = g_strdup(server->user);
+        if (need_passwd) {
+        	if ((server->passwd != NULL) && (server->passwd[0] != '\0')) {
+        		result[1] = g_strdup(server->passwd);
+        	} else {
+        		result[1] = libbalsa_server_get_password(server, NULL);
+        	}
+        }
+    }
+    return result;
+}
+
+
+gboolean
+libbalsa_server_check_cert(NetClient           *client,
+           	   	   	   	   GTlsCertificate     *peer_cert,
+						   GTlsCertificateFlags errors,
+						   gpointer             user_data)
+{
+    GByteArray *cert_der = NULL;
+    gboolean result = FALSE;
+
+    /* FIXME - this a hack, simulating the (OpenSSL based) input for libbalsa_is_cert_known().
+        If we switch completely to
+     * (GnuTLS based) GTlsCertificate/GTlsClientConnection, we can omit this... */
+    g_debug("%s: %p %p %u %p", __func__, client, peer_cert, errors, user_data);
+
+    /* create a OpenSSL X509 object from the certificate's DER data */
+    g_object_get(G_OBJECT(peer_cert), "certificate", &cert_der, NULL);
+    if (cert_der != NULL) {
+        X509 *ossl_cert;
+        const unsigned char *der_p;
+
+        der_p = (const unsigned char *) cert_der->data;
+        ossl_cert = d2i_X509(NULL, &der_p, cert_der->len);
+        g_byte_array_unref(cert_der);
+
+        if (ossl_cert != NULL) {
+            long vfy_result;
+
+            /* convert the GIO error flags into OpenSSL error flags */
+            if ((errors & G_TLS_CERTIFICATE_UNKNOWN_CA) == G_TLS_CERTIFICATE_UNKNOWN_CA) {
+                vfy_result = X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT;
+            } else if ((errors & G_TLS_CERTIFICATE_BAD_IDENTITY) ==
+                       G_TLS_CERTIFICATE_BAD_IDENTITY) {
+                vfy_result = X509_V_ERR_SUBJECT_ISSUER_MISMATCH;
+            } else if ((errors & G_TLS_CERTIFICATE_NOT_ACTIVATED) ==
+                       G_TLS_CERTIFICATE_NOT_ACTIVATED) {
+                vfy_result = X509_V_ERR_CERT_NOT_YET_VALID;
+            } else if ((errors & G_TLS_CERTIFICATE_EXPIRED) == G_TLS_CERTIFICATE_EXPIRED) {
+                vfy_result = X509_V_ERR_CERT_HAS_EXPIRED;
+            } else if ((errors & G_TLS_CERTIFICATE_REVOKED) == G_TLS_CERTIFICATE_REVOKED) {
+                vfy_result = X509_V_ERR_CERT_REVOKED;
+            } else {
+                vfy_result = X509_V_ERR_APPLICATION_VERIFICATION;
+            }
+
+            result = libbalsa_is_cert_known(ossl_cert, vfy_result);
+            X509_free(ossl_cert);
+        }
+    }
+
+    return result;
+}
+
+
+gchar *
+libbalsa_server_get_cert_pass(NetClient        *client,
+			  	  	  	  	  const GByteArray *cert_der,
+							  gpointer          user_data)
+{
+	/* FIXME - we just return the passphrase from the config, but we may also want to show a dialogue here... */
+	return g_strdup(LIBBALSA_SERVER(user_data)->cert_passphrase);
+}
+
+/* Test whether a server is reachable */
+
+typedef struct {
+    LibBalsaCanReachCallback * cb;
+    gpointer                   cb_data;
+    GObject                  * source_object;
+} CanReachInfo;
+
+static void
+libbalsa_server_can_reach_cb(GObject      * monitor,
+                             GAsyncResult * res,
+                             gpointer       user_data)
+{
+    CanReachInfo *info = user_data;
+    gboolean can_reach;
+
+    can_reach = g_network_monitor_can_reach_finish((GNetworkMonitor *) monitor, res, NULL);
+    info->cb(info->source_object, can_reach, info->cb_data);
+
+    g_object_unref(info->source_object);
+    g_free(info);
+}
+
+void
+libbalsa_server_test_can_reach_full(LibBalsaServer           * server,
+                                    LibBalsaCanReachCallback * cb,
+                                    gpointer                   cb_data,
+                                    GObject                  * source_object)
+{
+    CanReachInfo *info;
+    gchar *host;
+    gchar *colon;
+    GNetworkMonitor *monitor;
+    GSocketConnectable *address;
+
+    info = g_new(CanReachInfo, 1);
+    info->cb              = cb;
+    info->cb_data         = cb_data;
+    info->source_object = g_object_ref(source_object);
+
+    monitor = g_network_monitor_get_default();
+
+    host = g_strdup(server->host);
+    colon = strchr(host, ':');
+    if (colon != NULL) {
+    	colon[0] = '\0';
+    }
+    address = g_network_address_new(host, 0);
+    g_free(host);
+    g_network_monitor_can_reach_async(monitor, address, NULL,
+                                      libbalsa_server_can_reach_cb, info);
+    g_object_unref(address);
+}
+
+void
+libbalsa_server_test_can_reach(LibBalsaServer           * server,
+                               LibBalsaCanReachCallback * cb,
+                               gpointer                   cb_data)
+{
+    libbalsa_server_test_can_reach_full(server, cb, cb_data, (GObject *) server);
+}
