@@ -27,21 +27,12 @@
 
 #include "imap/libimap.h"
 #include "libbalsa.h"
+#include "net-client.h"
 
 #if defined(HAVE_LIBSECRET)
 #include <libsecret/secret.h>
 extern const SecretSchema *LIBBALSA_SERVER_SECRET_SCHEMA;
 #define libbalsa_free_password secret_password_free
-#elif defined (HAVE_GNOME_KEYRING)
-#include <gnome-keyring.h>
-
-#if defined(HAVE_GNOME_KEYRING_24)
-#define LIBBALSA_SERVER_KEYRING_SCHEMA GNOME_KEYRING_NETWORK_PASSWORD
-#else
-extern const GnomeKeyringPasswordSchema* LIBBALSA_SERVER_KEYRING_SCHEMA;
-#endif /* HAVE_GNOME_KEYRING_24 */
-
-#define libbalsa_free_password gnome_keyring_free_password
 #else
 #define libbalsa_free_password g_free
 #endif                          /* defined(HAVE_LIBSECRET) */
@@ -75,6 +66,10 @@ struct _LibBalsaServer {
     gchar *host;
     gchar *user;
     gchar *passwd;
+    NetClientCryptMode security;
+    gboolean client_cert;
+    gchar *cert_file;
+    gchar *cert_passphrase;
     /* We include SSL support in UI unconditionally to preserve config
      * between SSL and non-SSL builds. We just fail if SSL is requested
      * in non-SSL build. */
@@ -112,7 +107,31 @@ void libbalsa_server_save_config(LibBalsaServer * server);
 
 void libbalsa_server_user_cb(ImapUserEventType ue, void *arg, ...);
 
+/* NetClient related signal handlers */
+gchar **libbalsa_server_get_auth(NetClient *client,
+								 gboolean   need_passwd,
+								 gpointer   user_data);
+gboolean libbalsa_server_check_cert(NetClient           *client,
+           	   	   	   	   	   	    GTlsCertificate     *peer_cert,
+									GTlsCertificateFlags errors,
+									gpointer             user_data);
+gchar *libbalsa_server_get_cert_pass(NetClient        *client,
+									 const GByteArray *cert_der,
+									 gpointer          user_data);
+
 void libbalsa_server_connect_signals(LibBalsaServer * server, GCallback cb,
                                      gpointer cb_data);
 
+/* Check whether a server can be reached */
+
+void libbalsa_server_test_can_reach(LibBalsaServer           * server,
+                                    LibBalsaCanReachCallback * cb,
+                                    gpointer                   cb_data);
+
+/* Private: used only by LibBalsaMailboxRemote */
+void libbalsa_server_test_can_reach_full(LibBalsaServer           * server,
+                                         LibBalsaCanReachCallback * cb,
+                                         gpointer                   cb_data,
+                                         GObject                  * source_object);
+
 #endif				/* __LIBBALSA_SERVER_H__ */
