@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -40,26 +38,15 @@
 #include "server.h"
 #include "url.h"
 
-#if !defined(ENABLE_TOUCH_UI)
 #define INBOX_NAME    "Inbox"
 #define OUTBOX_NAME   "Outbox"
 #define SENTBOX_NAME  "Sentbox"
 #define DRAFTBOX_NAME "Draftbox"
-#else /* defined(ENABLE_TOUCH_UI) */
-#define INBOX_NAME    "In"
-#define OUTBOX_NAME   "Out"
-#define SENTBOX_NAME  "Sent"
-#define DRAFTBOX_NAME "Drafts"
-#endif /* defined(ENABLE_TOUCH_UI) */
 #define TRASH_NAME    "Trash"
 
 static const gchar * const init_mbnames[NUM_EDs] = {
-#if defined(ENABLE_TOUCH_UI)
-    "_In:", "_Out:", "_Sent:", "_Drafts:", "_Trash:"
-#else
     N_("_Inbox:"), N_("_Outbox:"), N_("_Sentbox:"), N_("_Draftbox:"),
     N_("_Trash:")
-#endif
 };
 
 static void balsa_druid_page_directory_prepare(GtkAssistant * druid,
@@ -93,8 +80,8 @@ unconditional_mailbox(const gchar * path, const gchar * prettyname,
     if (index == NULL) {
         (*error) =
             g_strdup_printf(_
-                            ("The pathname \"%s\" must be specified"
-                             " canonically -- it must start with a \'/\'."),
+                            ("The pathname “%s” must be specified"
+                             " canonically — it must start with a “/”."),
                             dup);
         g_free(dup);
         return;
@@ -134,7 +121,7 @@ unconditional_mailbox(const gchar * path, const gchar * prettyname,
         *box = libbalsa_mailbox_local_new(path, TRUE);
         if (!*box) {
             *error = g_strdup_printf(_("Could not create mailbox"
-                                       " at path \"%s\"\n"), path);
+                                       " at path “%s”\n"), path);
             g_free(dup);
             return;
         }
@@ -165,7 +152,7 @@ unconditional_mailbox(const gchar * path, const gchar * prettyname,
     if ( *box == NULL) {
             (*error) =
                 g_strdup_printf(_
-                                ("The mailbox \"%s\" does not appear to be valid."),
+                                ("The mailbox “%s” does not appear to be valid."),
                                 path);
         return;
     }
@@ -199,7 +186,7 @@ verify_mailbox_entry(GtkWidget * entry, const gchar * name,
                                    GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_ERROR,
                                    GTK_BUTTONS_OK,
-                                   _("Problem verifying path \"%s\":\n%s"),
+                                   _("Problem verifying path “%s”:\n%s"),
                                    text, error);
         g_free(error);
         gtk_dialog_run(GTK_DIALOG(dlg));
@@ -299,16 +286,11 @@ balsa_druid_page_directory_init(BalsaDruidPageDirectory * dir,
         else
             preset = g_strdup("[Dummy value]");
 
-#if defined(ENABLE_TOUCH_UI)
-        balsa_init_add_grid_entry(grid, i, init_mbnames[i], preset,
-                                   &(dir->ed[i]), druid, page, init_widgets[i]);
-#else
         entry = balsa_init_add_grid_entry(grid, i, _(init_mbnames[i]),
                                           preset, NULL, NULL, NULL,
                                           init_widgets[i]);
         g_signal_connect(entry, "changed",
                          G_CALLBACK(entry_changed_cb), dir);
-#endif
 
         g_free(preset);
     }
@@ -410,36 +392,3 @@ balsa_druid_page_directory_next(GtkAssistant * page, GtkWidget * druid,
 {
     dir->paths_locked = TRUE;
 }
-
-#if defined(ENABLE_TOUCH_UI)
-#define SET_MAILBOX(fname, config, mbx) \
-do { gchar *t=g_build_filename(balsa_app.local_mail_directory,(fname),NULL);\
- unconditional_mailbox(t, config, (mbx), &error); g_free(t);}while(0)
-
-void
-balsa_druid_page_directory_later(GtkWidget *druid)
-{
-    gchar *error = NULL;
-    gchar *spool = libbalsa_guess_mail_spool();
-    unconditional_mailbox(spool, INBOX_NAME, &balsa_app.inbox, &error);
-    g_free(spool);
-    SET_MAILBOX("trash",    TRASH_NAME,    &balsa_app.trash);
-    SET_MAILBOX("outbox",   OUTBOX_NAME,   &balsa_app.outbox);
-    SET_MAILBOX("sentbox",  SENTBOX_NAME,  &balsa_app.sentbox);
-    SET_MAILBOX("draftbox", DRAFTBOX_NAME, &balsa_app.draftbox);
-    if (error) {
-        GtkWidget *dlg =
-            gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_ancestor
-                                          (GTK_WIDGET(druid), 
-                                           GTK_TYPE_WINDOW)),
-                                   GTK_DIALOG_MODAL,
-                                   GTK_MESSAGE_ERROR,
-                                   GTK_BUTTONS_OK,
-                                   _("Problem Creating Mailboxes\n%s"),
-                                   error);
-        g_free(error);
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
-    }
-}
-#endif                          /* defined(ENABLE_TOUCH_UI) */
