@@ -216,8 +216,6 @@ bmbl_set_property_node_style(GSList * list)
     GSList *l;
     GtkTreePath *path;
 
-    gdk_threads_enter();
-
     for (l = list; l; l = l->next) {
         GtkTreeRowReference *reference = l->data;
         path = gtk_tree_row_reference_get_path(reference);
@@ -234,7 +232,6 @@ bmbl_set_property_node_style(GSList * list)
     }
 
     g_slist_free(list);
-    gdk_threads_leave();
 }
 
 static gboolean
@@ -691,7 +688,7 @@ bmbl_button_press_cb(GtkWidget * widget, GdkEventButton * event,
     GtkTreeView *tree_view = GTK_TREE_VIEW(widget);
     GtkTreePath *path;
 
-    if (event->type != GDK_BUTTON_PRESS || event->button != 3
+    if (!gdk_event_triggers_context_menu((GdkEvent *) event)
         || event->window != gtk_tree_view_get_bin_window(tree_view))
         return FALSE;
 
@@ -883,7 +880,6 @@ static void
 bmbl_select_mailbox(GtkTreeSelection * selection, gpointer data)
 {
     GdkEvent *event = gtk_get_current_event();
-    GtkTreeIter iter;
     GtkTreeView *tree_view =
         gtk_tree_selection_get_tree_view(selection);
     GtkTreeModel *model =
@@ -891,10 +887,9 @@ bmbl_select_mailbox(GtkTreeSelection * selection, gpointer data)
     GtkTreePath *path;
 
     if (!event) {
-	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
+	if (gtk_tree_selection_get_selected(selection, NULL, &iter)) {
 	    BalsaMailboxNode *mbnode;
 	    LibBalsaMailbox *mailbox;
 	    gtk_tree_model_get(model, &iter, MBNODE_COLUMN, &mbnode, -1);
@@ -937,6 +932,7 @@ bmbl_select_mailbox(GtkTreeSelection * selection, gpointer data)
 
     if (gtk_tree_selection_path_is_selected(selection, path)) {
         BalsaMailboxNode *mbnode;
+        GtkTreeIter iter;
 
         gtk_tree_model_get_iter(model, &iter, path);
         gtk_tree_model_get(model, &iter, MBNODE_COLUMN, &mbnode, -1);
@@ -1252,9 +1248,7 @@ balsa_mblist_close_lru_peer_mbx(BalsaMBList * mblist,
     dt.mbnode = NULL;
     gtk_tree_model_foreach(model, get_lru_descendant, &dt);
     if(dt.mbnode) {
-        gdk_threads_enter();
         balsa_window_close_mbnode(balsa_app.main_window, dt.mbnode);
-        gdk_threads_leave();
         g_object_unref(dt.mbnode);
     }
     return dt.mbnode != NULL;
@@ -2247,16 +2241,12 @@ bmbl_sort_idle(gpointer data)
 {
     GtkTreeSortable *sortable = data;
 
-    gdk_threads_enter();
-
     gtk_tree_sortable_set_sort_column_id(sortable,
                                          balsa_app.mblist->sort_column_id,
                                          GTK_SORT_ASCENDING);
     balsa_app.mblist->sort_idle_id = 0;
     g_object_unref(sortable);
 
-    gdk_threads_leave();
-
     return FALSE;
 }
 
@@ -2269,8 +2259,6 @@ balsa_mblist_mailbox_node_append(BalsaMailboxNode * root,
     GtkTreeIter *parent_iter = NULL;
     GtkTreeIter iter;
 
-    gdk_threads_enter();
-
     model = GTK_TREE_MODEL(balsa_app.mblist_tree_store);
 
     if (!balsa_app.mblist->sort_idle_id) {
@@ -2305,8 +2293,6 @@ balsa_mblist_mailbox_node_append(BalsaMailboxNode * root,
 
     /* The tree-store owns mbnode. */
     g_object_unref(mbnode);
-
-    gdk_threads_leave();
 }
 
 /* Rerender a row after its properties have changed. */
