@@ -300,12 +300,24 @@ static void
 extbody_call_url(GtkWidget * button, gpointer data)
 {
     gchar *url = g_object_get_data(G_OBJECT(button), "call_url");
+#if GTK_CHECK_VERSION(3, 22, 0)
+    GtkWidget *toplevel;
+#else /* GTK_CHECK_VERSION(3, 22, 0) */
     GdkScreen *screen;
+#endif /* GTK_CHECK_VERSION(3, 22, 0) */
     GError *err = NULL;
 
     g_return_if_fail(url);
+#if GTK_CHECK_VERSION(3, 22, 0)
+    toplevel = gtk_widget_get_toplevel(GTK_WIDGET(button));
+    if (gtk_widget_is_toplevel(toplevel)) {
+        gtk_show_uri_on_window(GTK_WINDOW(toplevel), url,
+                               gtk_get_current_event_time(), &err);
+    }
+#else  /* GTK_CHECK_VERSION(3, 22, 0) */
     screen = gtk_widget_get_screen(button);
     gtk_show_uri(screen, url, gtk_get_current_event_time(), &err);
+#endif /* GTK_CHECK_VERSION(3, 22, 0) */
     if (err) {
 	balsa_information(LIBBALSA_INFORMATION_WARNING,
 			  _("Error showing %s: %s\n"), url, err->message);
@@ -363,18 +375,13 @@ extbody_send_mail(GtkWidget * button, LibBalsaMessageBody * mime_body)
     else
 	body->charset = g_strdup("US-ASCII");
     libbalsa_message_append_part(message, body);
-#if ENABLE_ESMTP
     result = libbalsa_message_send(message, balsa_app.outbox, NULL,
 				   balsa_find_sentbox_by_url,
 				   balsa_app.current_ident->smtp_server,
+				   balsa_app.send_progress_dialog,
                                    GTK_WINDOW(gtk_widget_get_toplevel
                                               (button)),
-				   FALSE, balsa_app.debug, &err);
-#else
-    result = libbalsa_message_send(message, balsa_app.outbox, NULL,
-				   balsa_find_sentbox_by_url,
-				   FALSE, balsa_app.debug, &err);
-#endif
+				   FALSE, &err);
     if (result != LIBBALSA_MESSAGE_CREATE_OK)
 	libbalsa_information(LIBBALSA_INFORMATION_ERROR,
 			     _("Sending the external body request failed: %s"),
@@ -614,13 +621,6 @@ add_header_gchar(GtkGrid * grid, const gchar * header, const gchar * label,
         gtk_label_set_line_wrap(GTK_LABEL(value_label), TRUE);
         gtk_label_set_line_wrap_mode(GTK_LABEL(value_label), PANGO_WRAP_WORD_CHAR);
         gtk_label_set_selectable(GTK_LABEL(value_label), TRUE);
-#if GTK_CHECK_VERSION(3, 16, 0)
-        gtk_label_set_xalign((GtkLabel *) value_label, 0.0);
-#else                           /* GTK_CHECK_VERSION(3, 16, 0) */
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-        gtk_misc_set_alignment((GtkMisc *) value_label, 0.0, 0.0);
-G_GNUC_END_IGNORE_DEPRECATIONS
-#endif                          /* GTK_CHECK_VERSION(3, 16, 0) */
         gtk_widget_set_halign(value_label, GTK_ALIGN_START);
         gtk_widget_set_hexpand(value_label, TRUE);
 
@@ -677,11 +677,12 @@ add_header_address_list(BalsaMessage * bm, GtkGrid * grid,
 static void
 foreach_label(GtkWidget * widget, LibBalsaMessageBody * part)
 {
+    g_assert(widget != NULL);
+
     if (GTK_IS_CONTAINER(widget))
-        gtk_container_foreach(GTK_CONTAINER(widget),
+        gtk_container_foreach((GtkContainer *) widget,
                               (GtkCallback) foreach_label, part);
-    else if (g_signal_lookup("populate-popup",
-                             G_TYPE_FROM_INSTANCE(widget)))
+    else if (GTK_IS_LABEL(widget))
         g_signal_connect(widget, "populate-popup",
                          G_CALLBACK(bm_header_extend_popup), part);
 }
@@ -848,7 +849,7 @@ add_header_sigstate(GtkGrid * grid, GMimeGpgmeSigstat * siginfo)
         GPG_ERR_NO_ERROR ? "<i>%s%s</i>" : "<b><i>%s%s</i></b>";
     msg = g_markup_printf_escaped
         (format,
-         libbalsa_gpgme_sig_protocol_name(siginfo->protocol),
+        	g_mime_gpgme_sigstat_protocol_name(siginfo),
          libbalsa_gpgme_sig_stat_to_gchar(siginfo->status));
 
     label = gtk_label_new(NULL);
