@@ -28,7 +28,7 @@
 #include "filter-run.h"
 #include "mailbox-filter.h"
 #include "save-restore.h"
-#include "libbalsa/filter-funcs.h"
+#include "filter-funcs.h"
 #include <glib/gi18n.h>
 
 /* fe_already_open is TRUE when the filters dialog is opened, we use
@@ -179,11 +179,16 @@ balsa_filter_run_dialog_new(LibBalsaMailbox * mbox, GtkWindow * parent)
 {
     BalsaFilterRunDialog *p;
     gchar * dialog_title;
+    gboolean use_headerbar = TRUE;
 
     g_return_val_if_fail(mbox, NULL);
+
+#if GTK_CHECK_VERSION(3, 12, 0)
+    use_headerbar = (libbalsa_dialog_flags() & GTK_DIALOG_USE_HEADER_BAR) != 0;
+#endif
     p = g_object_new(BALSA_TYPE_FILTER_RUN_DIALOG,
                      "transient-for", parent,
-                     "use-header-bar", TRUE,
+                     "use-header-bar", use_headerbar,
                      NULL);
 
     /* We set the dialog title */
@@ -487,8 +492,8 @@ filters_run_dialog(LibBalsaMailbox * mbox,
     }
     /* We look for an existing dialog box for this mailbox */
     for (lst = fr_dialogs_opened; lst; lst = g_list_next(lst)) {
-        BalsaFilterRunDialog *p = lst->data;
-        if (strcmp(p->mbox->url, mbox->url) == 0)
+        BalsaFilterRunDialog *dialog = lst->data;
+        if (strcmp(dialog->mbox->url, mbox->url) == 0)
             break;
     }
     if (lst) {
