@@ -1,6 +1,6 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
- * Copyright (C) 1997-2013 Stuart Parmenter and others,
+ * Copyright (C) 1997-2016 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __INFORMATION_DIALOG_H__
@@ -34,18 +32,12 @@ enum _BalsaInformationShow {
 };
 
 void balsa_information(LibBalsaInformationType type, const char *fmt, ...)
-#ifdef __GNUC__
-    __attribute__ ((format (printf, 2, 3)))
-#endif
-;
+	G_GNUC_PRINTF(2, 3);
 
 void balsa_information_parented(GtkWindow *widget,
                                 LibBalsaInformationType type, 
                                 const char *fmt, ...)
-#ifdef __GNUC__
-    __attribute__ ((format (printf, 3, 4)));
-#endif
-;
+	G_GNUC_PRINTF(3, 4);
 
 void balsa_information_real(GtkWindow *parent, LibBalsaInformationType type,
                             const char *msg);
