@@ -47,7 +47,6 @@
 #include "information.h"
 #include "imap-server.h"
 #include "libbalsa-conf.h"
-#include "threads.h"
 
 #include "libinit_balsa/assistant_init.h"
 
@@ -56,19 +55,6 @@
 #include "libbalsa-gpgme-cb.h"
 #endif
 
-/* Globals for Thread creation, messaging, pipe I/O */
-GMutex send_messages_lock;
-gboolean checking_mail;
-int mail_thread_pipes[2];
-int send_thread_pipes[2];
-GIOChannel *mail_thread_msg_send;
-GIOChannel *mail_thread_msg_receive;
-GIOChannel *send_thread_msg_send;
-GIOChannel *send_thread_msg_receive;
-
-static void threads_init(void);
-static void threads_destroy(void);
-
 static void config_init(gboolean check_only);
 static void mailboxes_init(gboolean check_only);
 static void balsa_cleanup(void);
@@ -107,7 +93,7 @@ accel_map_save(void)
 static gboolean
 balsa_main_check_new_messages(gpointer data)
 {
-    check_new_messages_real(data, TYPE_CALLBACK);
+    check_new_messages_real(data, FALSE);
     return FALSE;
 }
 
@@ -172,51 +158,15 @@ mailboxes_init(gboolean check_only)
     }
 }
 
-GMutex checking_mail_lock;
-
-static void
-threads_init(void)
-{
-    g_mutex_init(&send_messages_lock);
-    if (pipe(mail_thread_pipes) < 0) {
-	g_log("BALSA Init", G_LOG_LEVEL_DEBUG,
-	      "Error opening pipes.\n");
-    }
-    mail_thread_msg_send = g_io_channel_unix_new(mail_thread_pipes[1]);
-    mail_thread_msg_receive =
-	g_io_channel_unix_new(mail_thread_pipes[0]);
-    g_io_add_watch(mail_thread_msg_receive, G_IO_IN,
-		   (GIOFunc) mail_progress_notify_cb,
-                   &balsa_app.main_window);
-
-    if (pipe(send_thread_pipes) < 0) {
-	g_log("BALSA Init", G_LOG_LEVEL_DEBUG,
-	      "Error opening pipes.\n");
-    }
-    send_thread_msg_send = g_io_channel_unix_new(send_thread_pipes[1]);
-    send_thread_msg_receive =
-	g_io_channel_unix_new(send_thread_pipes[0]);
-    g_io_add_watch(send_thread_msg_receive, G_IO_IN,
-		   (GIOFunc) send_progress_notify_cb,
-                   &balsa_app.main_window);
-}
-
-static void
-threads_destroy(void)
-{
-    g_mutex_clear(&checking_mail_lock);
-    g_mutex_clear(&send_messages_lock);
-}
 
 /* initial_open_mailboxes:
    open mailboxes on startup if requested so.
-   This is an idle handler. Be sure to use gdk_threads_{enter/leave}
+   This is an idle handler.
  */
 static gboolean
 initial_open_unread_mailboxes()
 {
     GList *l, *gl;
-    gdk_threads_enter();
     gl = balsa_mblist_find_all_unread_mboxes(NULL);
 
     if (gl) {
@@ -228,7 +178,6 @@ initial_open_unread_mailboxes()
         }
         g_list_free(gl);
     }
-    gdk_threads_leave();
     return FALSE;
 }
 
@@ -240,9 +189,7 @@ initial_open_inbox()
 	return FALSE;
 
     printf("opening %s..\n", balsa_app.inbox->name);
-    gdk_threads_enter();
     balsa_mblist_open_mailbox_hidden(balsa_app.inbox);
-    gdk_threads_leave();
 
     return FALSE;
 }
@@ -253,10 +200,8 @@ balsa_get_stats(long *unread, long *unsent)
 
     if(balsa_app.inbox && libbalsa_mailbox_open(balsa_app.inbox, NULL) ) {
         /* set threading type to load messages */
-        gdk_threads_enter();
         libbalsa_mailbox_set_threading(balsa_app.inbox,
                                        balsa_app.inbox->view->threading_type);
-        gdk_threads_leave();
         *unread = balsa_app.inbox->unread_messages;
         libbalsa_mailbox_close(balsa_app.inbox, FALSE);
     } else *unread = -1;
@@ -299,7 +244,6 @@ scan_mailboxes_idle_cb()
     GtkTreeIter iter;
     GPtrArray *url_array;
 
-    gdk_threads_enter();
     model = GTK_TREE_MODEL(balsa_app.mblist_tree_store);
     /* The model contains only nodes from config. */
     for (valid = gtk_tree_model_get_iter_first(model, &iter); valid;
@@ -313,7 +257,6 @@ scan_mailboxes_idle_cb()
     /* The root-node (typically ~/mail) isn't in the model, so its
      * children will be appended to the top level. */
     balsa_mailbox_node_append_subtree(balsa_app.root_node);
-    gdk_threads_leave();
 
     url_array = g_ptr_array_new();
     if (cmd_open_unread_mailbox || balsa_app.open_unread_mailbox){
@@ -396,13 +339,11 @@ periodic_expunge_cb(void)
     /* should we enforce expunging now and then? Perhaps not... */
     if(!balsa_app.expunge_auto) return TRUE;
 
-    gdk_threads_enter();
     libbalsa_information(LIBBALSA_INFORMATION_DEBUG,
                          _("Compressing mail folders…"));
     gtk_tree_model_foreach(GTK_TREE_MODEL(balsa_app.mblist_tree_store),
 			   (GtkTreeModelForeachFunc)mbnode_expunge_func,
 			   &list);
-    gdk_threads_leave();
 
     for (l = list; l; l = l->next) {
         BalsaMailboxNode *mbnode = l->data;
@@ -478,24 +419,20 @@ balsa_progress_set_fraction(LibBalsaProgress * progress, gdouble fraction)
     g_time_val_add(&time_val, LIBBALSA_PROGRESS_MIN_UPDATE_USECS);
     min_fraction += LIBBALSA_PROGRESS_MIN_UPDATE_STEP;
 
-    gdk_threads_enter();
     if (balsa_app.main_window)
         balsa_window_increment_progress(balsa_app.main_window, fraction,
                                         !libbalsa_am_i_subthread());
-    gdk_threads_leave();
 }
 
 static void
 balsa_progress_set_activity(gboolean set, const gchar * text)
 {
-    gdk_threads_enter();
     if (balsa_app.main_window) {
         if (set)
             balsa_window_increase_activity(balsa_app.main_window, text);
         else
             balsa_window_decrease_activity(balsa_app.main_window, text);
     }
-    gdk_threads_leave();
 }
 
 static gboolean
@@ -546,9 +483,6 @@ real_main(int argc, char *argv[])
     setlocale(LC_ALL, "");
 #endif
 
-    /* initiate thread mutexs, variables */
-    threads_init();
-
 #ifdef HAVE_RUBRICA
     /* initialise libxml */
     LIBXML_TEST_VERSION
@@ -571,6 +505,8 @@ real_main(int argc, char *argv[])
     libbalsa_progress_set_fraction = balsa_progress_set_fraction;
     libbalsa_progress_set_activity = balsa_progress_set_activity;
 
+    libbalsa_mailbox_date_format = &balsa_app.date_string;
+
     /* checking for valid config files */
     config_init(cmd_get_stats);
 
@@ -609,7 +545,17 @@ real_main(int argc, char *argv[])
     balsa_check_open_compose_window();
 
     g_idle_add((GSourceFunc) scan_mailboxes_idle_cb, NULL);
-    g_idle_add((GSourceFunc) balsa_window_fix_paned, balsa_app.main_window);
+    if (balsa_app.mw_maximized) {
+        /*
+         * When maximized at startup, the window changes from maximized
+         * to not maximized a couple of times, so we wait until it has
+         * stabilized (100 msec is not enough!).
+         */
+        g_timeout_add(800, (GSourceFunc) balsa_window_fix_paned, balsa_app.main_window);
+    } else {
+        /* No need to wait. */
+        g_idle_add((GSourceFunc) balsa_window_fix_paned, balsa_app.main_window);
+    }
     g_timeout_add_seconds(1801, (GSourceFunc) periodic_expunge_cb, NULL);
 
     if (cmd_check_mail_on_startup || balsa_app.check_mail_upon_startup)
@@ -617,15 +563,11 @@ real_main(int argc, char *argv[])
                    balsa_app.main_window);
 
     accel_map_load();
-    gdk_threads_enter();
     gtk_main();
-    gdk_threads_leave();
 
     balsa_cleanup();
     accel_map_save();
 
-    threads_destroy();
-
     libbalsa_imap_server_close_all_connections();
     return 0;
 }
@@ -669,8 +611,6 @@ parse_options(int                       argc,
         {"get-stats", 's', 0, G_OPTION_ARG_NONE,
          &(cmd_get_stats),
          N_("Prints number unread and unsent messages"), NULL},
-        {"debug-pop", 'd', 0, G_OPTION_ARG_NONE, &PopDebug,
-         N_("Debug POP3 connection"), NULL},
         {"debug-imap", 'D', 0, G_OPTION_ARG_NONE, &ImapDebug,
          N_("Debug IMAP connection"), NULL},
         {"help", 'h', 0, G_OPTION_ARG_NONE, &help, N_("Show help options"), NULL},
@@ -762,8 +702,6 @@ handle_remote(int argc, char **argv,
                                          "Unread: %ld Unsent: %ld\n",
                                          unread, unsent);
     } else {
-        gdk_threads_enter();
-
         if (cmd_check_mail_on_startup)
             balsa_main_check_new_messages(balsa_app.main_window);
 
@@ -780,8 +718,6 @@ handle_remote(int argc, char **argv,
             /* Move the main window to the request's screen */
             gtk_window_present(GTK_WINDOW(balsa_app.main_window));
         }
-
-        gdk_threads_leave();
     }
 }
 
@@ -827,12 +763,6 @@ main(int argc, char **argv)
     GtkApplication *application;
     int status;
 
-# if defined(USE_WEBKIT2)
-    /* temporary fix to avoid some webkit warnings, if the user has not
-     * set it: */
-    g_setenv("WEBKIT_DISABLE_COMPOSITING_MODE", "1", FALSE);
-#endif                          /* defined(USE_WEBKIT2) */
-
     balsa_app.application = application =
         gtk_application_new("org.desktop.Balsa",
                             G_APPLICATION_HANDLES_COMMAND_LINE);
